package com.ruoyi.cs.service;

import java.util.List;
import com.ruoyi.cs.domain.CsFile;

/**
 * 文件上传Service接口
 * 
 * @author ruoyi
 * @date 2024-10-12
 */
public interface ICsFileService 
{
    /**
     * 查询文件上传
     * 
     * @param fileId 文件上传主键
     * @return 文件上传
     */
    public CsFile selectCsFileByFileId(String fileId);

    /**
     * 查询文件上传列表
     * 
     * @param csFile 文件上传
     * @return 文件上传集合
     */
    public List<CsFile> selectCsFileList(CsFile csFile);

    /**
     * 新增文件上传
     * 
     * @param csFile 文件上传
     * @return 结果
     */
    public int insertCsFile(CsFile csFile);

    /**
     * 修改文件上传
     * 
     * @param csFile 文件上传
     * @return 结果
     */
    public int updateCsFile(CsFile csFile);

    /**
     * 批量删除文件上传
     * 
     * @param fileIds 需要删除的文件上传主键集合
     * @return 结果
     */
    public int deleteCsFileByFileIds(String[] fileIds);

    /**
     * 删除文件上传信息
     * 
     * @param fileId 文件上传主键
     * @return 结果
     */
    public int deleteCsFileByFileId(String fileId);
}
